package com.example.viewer;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.ContentUris;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.database.Cursor;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.os.Environment;
import android.provider.DocumentsContract;
import android.provider.MediaStore;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import android.widget.FrameLayout;
import android.widget.RelativeLayout;
import android.widget.Toast;
import com.dermandar.viewerlibrary.DMDViewer;

public class SampleActivity extends Activity {

	RelativeLayout relativeLayout;
	private FrameLayout mFrameLayout;
    String imagePath;
	DMDViewer sv;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		this.requestWindowFeature(Window.FEATURE_NO_TITLE);
		this.getWindow().setFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN,
				WindowManager.LayoutParams.FLAG_FULLSCREEN);

		setContentView(R.layout.activity_samlpe);
		
		relativeLayout = (RelativeLayout) findViewById(R.id.relativeLayoutRoot);
		Intent intent = new Intent(Intent.ACTION_GET_CONTENT);
		intent.setType("image/*");
		startActivityForResult(intent, 0);
		
		sv = new DMDViewer();
		//setContentView(sv.init(getApplicationContext()));
	}
	@Override
	protected void onPause() {
		super.onPause();
		sv.pause();
	}
	
	@Override
	protected void onResume() {
		super.onResume();
		sv.resume();
	}
	
	@Override
	protected void onActivityResult(int reqCode, int resCode, Intent data) {
		
		if(data == null) return;
		Uri selectedImageURI = data.getData();
		imagePath = getPath2(this, selectedImageURI);

        final Context cont = this;

        AlertDialog.Builder builder = new AlertDialog.Builder(this)
                .setTitle("Panorama Type")
                .setMessage("Please select which type to use")
                .setPositiveButton("Spherical", new DialogInterface.OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialog, int which) {
                        String viewerType = "s"; //s: spherical
                        int fov = 360; // spherical supports 360 only
                        final View v = sv.init(getApplicationContext(),imagePath,fov,viewerType,new DMDViewer.DMDViewerCallBacks() {

                            @Override
                            public void onReleased() {

                            }

                            @Override
                            public void afterPanoLoad() {

                            }

                            @Override
                            public void onFinishLoading(boolean success) {
                                if(!success)
                                {
                                    runOnUiThread(new Runnable() {
                                        public void run() {
                                            Toast.makeText(getApplicationContext(), "image not supported", Toast.LENGTH_LONG).show();
                                        }
                                    });
                                }
                            }
                        });
                        relativeLayout.addView(v);
                    }
                })
                .setNegativeButton("Cylindrical", new DialogInterface.OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialog, int which) {

                        String viewerType = "c"; // c: cylindrical
                        int fov = 150; //field of view
                        final View v = sv.init(getApplicationContext(),imagePath,fov,viewerType,new DMDViewer.DMDViewerCallBacks() {

                            @Override
                            public void onReleased() {

                            }

                            @Override
                            public void afterPanoLoad() {

                            }

                            @Override
                            public void onFinishLoading(boolean success) {
                                if(!success)
                                {
                                    runOnUiThread(new Runnable() {
                                        public void run() {
                                            Toast.makeText(getApplicationContext(), "image not supported", Toast.LENGTH_LONG).show();
                                        }
                                    });
                                }
                            }
                        });
                        relativeLayout.addView(v);
                    }
                });
        builder.show();
	}

    public static String getPath2(final Context context, final Uri uri) {

        final boolean isKitKat = Build.VERSION.SDK_INT >= Build.VERSION_CODES.KITKAT;

        if (isKitKat && DocumentsContract.isDocumentUri(context, uri)) {
            if (isExternalStorageDocument(uri)) {
                final String docId = DocumentsContract.getDocumentId(uri);
                final String[] split = docId.split(":");
                final String type = split[0];

                if ("primary".equalsIgnoreCase(type)) {
                    return Environment.getExternalStorageDirectory() + "/" + split[1];
                }
            }
            else if (isDownloadsDocument(uri)) {

                final String id = DocumentsContract.getDocumentId(uri);
                final Uri contentUri = ContentUris.withAppendedId(
                        Uri.parse("content://downloads/public_downloads"), Long.valueOf(id));

                return getDataColumn(context, contentUri, null, null);
            }
            else if (isMediaDocument(uri)) {
                final String docId = DocumentsContract.getDocumentId(uri);
                final String[] split = docId.split(":");
                final String type = split[0];

                Uri contentUri = null;
                if ("image".equals(type)) {
                    contentUri = MediaStore.Images.Media.EXTERNAL_CONTENT_URI;
                } else if ("video".equals(type)) {
                    contentUri = MediaStore.Video.Media.EXTERNAL_CONTENT_URI;
                } else if ("audio".equals(type)) {
                    contentUri = MediaStore.Audio.Media.EXTERNAL_CONTENT_URI;
                }

                final String selection = "_id=?";
                final String[] selectionArgs = new String[] {
                        split[1]
                };

                return getDataColumn(context, contentUri, selection, selectionArgs);
            }
        }
        else if ("content".equalsIgnoreCase(uri.getScheme())) {

            if (isGooglePhotosUri(uri))
                return uri.getLastPathSegment();

            return getDataColumn(context, uri, null, null);
        }
        else if ("file".equalsIgnoreCase(uri.getScheme())) {
            return uri.getPath();
        }

        return null;
    }

    public static String getDataColumn(Context context, Uri uri, String selection, String[] selectionArgs) {

        Cursor cursor = null;
        final String column = "_data";
        final String[] projection = {
                column
        };

        try {
            cursor = context.getContentResolver().query(uri, projection, selection, selectionArgs,null);
            if (cursor != null && cursor.moveToFirst()) {
                final int index = cursor.getColumnIndexOrThrow(column);
                return cursor.getString(index);
            }
        } finally {
            if (cursor != null)
                cursor.close();
        }
        return null;
    }

    public static boolean isExternalStorageDocument(Uri uri) {
        return "com.android.externalstorage.documents".equals(uri.getAuthority());
    }

    public static boolean isDownloadsDocument(Uri uri) {
        return "com.android.providers.downloads.documents".equals(uri.getAuthority());
    }

    public static boolean isMediaDocument(Uri uri) {
        return "com.android.providers.media.documents".equals(uri.getAuthority());
    }

    public static boolean isGooglePhotosUri(Uri uri) {
        return "com.google.android.apps.photos.content".equals(uri.getAuthority());
    }
}
